@@ -1,5 +1,6 @@
 from cursesplus import *
 from cursesplus import filedialog
+from cursesplus import progressbars
 
 def __test__(stdscr):
     import random
@@ -14,7 +15,10 @@ def __test__(stdscr):
     #p.done()
     #del p
     #displaymsg(stdscr,[filedialog.openfiledialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]])])
-    displaymsg(stdscr,filedialog.openfilesdialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]]))
+    #displaymsg(stdscr,str(cursesinput(stdscr,"HI").endswith(" ")))
+    #displaymsg(stdscr,filedialog.openfilesdialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]]))
+    progressbars.readfile_progress_bar(stdscr,"/usr/bin/gcc")
+    progressbars.writefile_progress_bar(stdscr,"bytes.txt","".join([chr(random.randint(0,255)) for _ in range(1000000)]).encode())
 
 if __name__ == "__main__":
     #Testing things
